==================
molfeat Change Log
==================

.. current developments

v0.8.3
====================

**Added:**

* More documentation and tutorials
* pip dependencies and optional dependencies in pyproject.toml
* Github issue templates

**Changed:**

* Updated all occurrences of old molfeat links with new ones.
* Documentation and readme

**Removed:**

* duplicated CODEOWNER file

**Fixed:**

* Bug in serialization of transformers with a serializable calculator
* Minor typos and function definition
* Links in pyprojects

**Authors:**

* Cas Wognum
* Hadrien Mary
* Honore Hounwanou
* Saurav Maheshkar
* Therence
* maclandrol



v0.8.1
====================

**Added:**

* Extended the simple benchmark in the docs to also include a search benchmark, based on the RDKit benchmarking platform
* Added missing API documentation for `molfeat.plugins` and `molfeat.store`.

**Changed:**

* Changed the styling of the docs to match the new datamol.io styling.

**Authors:**

* Cas Wognum
* Hadrien Mary
* Therence



v0.8.0
====================

**Authors:**

* Hadrien Mary


